@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -51,7 +51,7 @@ ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
     , mMode(mode)
 {
     setModal(true);
-    setWindowTitle(i18n("PIM Import Tool"));
+    setWindowTitle(i18nc("@title:window", "PIM Import Tool"));
     setStandardButtons(QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     mAbstractDisplayInfo = new ImportWizardDisplayInfo(this);
 
